**Example 1: 查询标签键**



Input: 

```
tccli tag DescribeTagKeys --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "TotalCount": 9,
        "Offset": 0,
        "Limit": 15,
        "Tags": [
            "test2",
            "test1",
            "0",
            "字符串",
            "test",
            "abcbbbb",
            "abcaaaaa",
            "abc",
            "测试"
        ],
        "RequestId": "cec4f865-bc87-4858-994e-80771644094d"
    }
}
```

